"""OAuth namespace package.

Use:
- `belgie.oauth.server` for OAuth server symbols
- `belgie.oauth.google` for Google OAuth client symbols
- `belgie.oauth.microsoft` for Microsoft OAuth client symbols
"""
